LazyDataset
===========

.. currentmodule:: pykeen.datasets.base

.. autoclass:: LazyDataset
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LazyDataset.testing
      ~LazyDataset.training
      ~LazyDataset.validation

   .. rubric:: Attributes Documentation

   .. autoattribute:: testing
   .. autoattribute:: training
   .. autoattribute:: validation
